==> rhoar-spring-boot-2.5.12-src.zip: rhoar-spring-boot-2.5.12.GA-src/Dekorate-2.5/tests/issue-446-secret-volumes/src/test/java/io/dekorate/annotationless/Issue446Test.java <==
/**
 * Copyright 2018 The original authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.dekorate.annotationless;

import static org.junit.jupiter.api.Assertions.*;

import java.util.Optional;

import org.junit.jupiter.api.Test;

import io.dekorate.utils.Serialization;
import io.fabric8.kubernetes.api.model.*;
import io.fabric8.kubernetes.api.model.apps.Deployment;

public class Issue446Test {

  @Test
  public void shouldContainComponent() {
    KubernetesList list = Serialization
        .unmarshalAsList(Issue446Test.class.getClassLoader().getResourceAsStream("META-INF/dekorate/kubernetes.yml"));
    assertNotNull(list);
    Deployment d = findFirst(list, Deployment.class).orElseThrow(() -> new IllegalStateException());
    assertNotNull(d);
    PodSpec p = d.getSpec().getTemplate().getSpec();
    assertNotNull(p);
    Volume volume = p.getVolumes().get(0);
    assertEquals("greeting-security", volume.getSecret().getSecretName());
    assertEquals("github-token", volume.getName());

    Container c = p.getContainers().get(0);
    assertNotNull(c);
    VolumeMount mount = c.getVolumeMounts().get(0);
    assertTrue(mount.getReadOnly());
  }

  <T extends HasMetadata> Optional<T> findFirst(KubernetesList list, Class<T> t) {
    return (Optional<T>) list.getItems().stream()
        .filter(i -> t.isInstance(i))
        .findFirst();
  }
}

==> rhoar-spring-boot-2.7.2-src.zip: rhoar-spring-boot-2.7.2.GA-src/Dekorate-2.11.5/tests/issue-446-secret-volumes/src/test/java/io/dekorate/annotationless/Issue446Test.java <==
/**
 * Copyright 2018 The original authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.dekorate.annotationless;

import static org.junit.jupiter.api.Assertions.*;

import java.util.Optional;

import org.junit.jupiter.api.Test;

import io.dekorate.utils.Serialization;
import io.fabric8.kubernetes.api.model.*;
import io.fabric8.kubernetes.api.model.apps.Deployment;

public class Issue446Test {

  @Test
  public void shouldContainComponent() {
    KubernetesList list = Serialization
        .unmarshalAsList(Issue446Test.class.getClassLoader().getResourceAsStream("META-INF/dekorate/kubernetes.yml"));
    assertNotNull(list);
    Deployment d = findFirst(list, Deployment.class).orElseThrow(() -> new IllegalStateException());
    assertNotNull(d);
    PodSpec p = d.getSpec().getTemplate().getSpec();
    assertNotNull(p);
    Volume firstVolume = p.getVolumes().get(0);
    assertEquals("greeting-security", firstVolume.getSecret().getSecretName());
    assertEquals("github-token", firstVolume.getName());

    Volume secondVolume = p.getVolumes().get(1);
    assertEquals("certs-secret", secondVolume.getSecret().getSecretName());
    assertEquals(2, secondVolume.getSecret().getItems().size());
    assertKeyPathItem("keystore", "keystore.jks", secondVolume.getSecret().getItems().get(0));
    assertKeyPathItem("pass", "password", secondVolume.getSecret().getItems().get(1));
    assertEquals("certs", secondVolume.getName());

    Container c = p.getContainers().get(0);
    assertNotNull(c);
    VolumeMount mount = c.getVolumeMounts().get(0);
    assertTrue(mount.getReadOnly());
  }

  <T extends HasMetadata> Optional<T> findFirst(KubernetesList list, Class<T> t) {
    return (Optional<T>) list.getItems().stream()
        .filter(i -> t.isInstance(i))
        .findFirst();
  }

  private void assertKeyPathItem(String expectedKey, String expectedPath, KeyToPath actualItem) {
    assertEquals(expectedKey, actualItem.getKey());
    assertEquals(expectedPath, actualItem.getPath());
  }
}
